@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2020-07-20 16:43:00 +0300 (Mon, 20 Jul 2020) $
-#$Revision: 8230 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.1.0/src/lib/perl5/COD/CIF/Data/CIF2COD.pm $
+#$Date: 2022-09-19 10:31:20 +0300 (Mon, 19 Sep 2022) $
+#$Revision: 9405 $
+#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.8.1/src/lib/perl5/COD/CIF/Data/CIF2COD.pm $
 #------------------------------------------------------------------------------
 #*
 #  Parse a CIF file, prepare a COD database table entry from it.
@@ -12,8 +12,10 @@ package COD::CIF::Data::CIF2COD;
 
 use strict;
 use warnings;
+
 use COD::Cell qw( cell_volume );
-use COD::CIF::Data qw( get_cell get_formula_units_z );
+use COD::CIF::Data qw( get_cell
+                       get_formula_units_z );
 use COD::CIF::Data::CellContents qw( cif_cell_contents );
 use COD::CIF::Data::CODFlags qw( is_disordered has_coordinates has_Fobs );
 use COD::CIF::Data::Check qw( check_formula_sum_syntax );
@@ -22,6 +24,7 @@ use COD::CIF::Unicode2CIF qw( cif2unicode );
 use COD::CIF::Tags::Manage qw( cifversion get_data_value get_aliased_value );
 use COD::CIF::Tags::DictTags;
 use COD::Spacegroups::Names;
+
 use Scalar::Util qw( looks_like_number );
 use List::MoreUtils qw( uniq none any );
 
@@ -33,8 +36,8 @@ our @EXPORT_OK = qw(
     @default_data_fields
 );
 
-# The default sql table data field that was taken from the
-# cod-add-data.sh script.
+# NOTE: the 'sgNumber' field was purposely excluded
+# from the default field list for now.
 our @default_data_fields = qw (
     file
     a
@@ -130,8 +133,12 @@ my %text_value_fields2tags = (
    'radiation'      => [ qw( _diffrn_radiation_probe ) ],
    'radType'        => [ qw( _diffrn_radiation_type ) ],
    'radSymbol'      => [ qw( _diffrn_radiation_xray_symbol ) ],
+   'sgNumber'       => [ qw( _space_group.IT_number
+                             _space_group_IT_number
+                             _symmetry.Int_Tables_number
+                             _symmetry_Int_Tables_number ) ],
    'duplicateof'    => [ qw( _cod_related_duplicate_entry.code
-                             _cod_related_duplicate_entry_code 
+                             _cod_related_duplicate_entry_code
                              _cod_duplicate_entry
                              _[local]_cod_duplicate_entry ) ],
    'optimal'        => [ qw( _cod_related_optimal_entry.code
@@ -227,7 +234,7 @@ my %space_groups = map {
 #       # Boolean value. Default '0'.
 #       # Include the implicit hydrogen atoms into the summary chemical formula.
 #       # The implicit hydrogen atoms are specified using
-#       # the _atom_site_attached_hydrogens data item. 
+#       # the _atom_site_attached_hydrogens data item.
 #           'use_attached_hydrogens' => 1,
 #       # Boolean value. Default '1'.
 #       # Accept data blocks without fractional coordinates.
@@ -316,12 +323,12 @@ sub cif2cod
     };
 
     # Set undef if the current value is an empty string
-    my $empty_value_regex = qr/^[\s?]*$/s;
+    my $empty_value_regex = qr/^[\s.?]*$/s;
     for ( qw( celltemp      sigcelltemp
               diffrtemp     sigdiffrtemp
               cellpressure  sigcellpressure
               diffrpressure sigdiffrpressure
-              formula chemname commonname mineral
+              formula chemname commonname mineral compoundsource
               journal year volume issue firstpage lastpage ) ) {
         if ( defined $data{$_} ) {
             if ( $data{$_} =~ $empty_value_regex ) {
@@ -332,6 +339,7 @@ sub cif2cod
 
     # Convert CIF notation to Unicode
     for ( qw( chemname commonname mineral
+              compoundsource
               radType radSymbol
               journal title ) ) {
         if ( defined $data{$_} &&
@@ -484,14 +492,14 @@ sub calculate_formula_sum
     }
 
     # FIXME: the local formula mitigations were a quick fix, however,
-    # it would be worthwhile to investingate and correct the issue
+    # it would be worthwhile to investigate and correct the issue
     # in the formula generation subroutine
     if ( defined $formula ) {
-        # Mitigate formula generated by unknown ('?') atomic coordinates 
+        # Mitigate formula generated by unknown ('?') atomic coordinates
         if ( $formula =~ m/^[?][0-9.]*$/ ) {
             return undef;
         }
-        # Mitigate formula generated by inapplicable ('.') atomic coordinates 
+        # Mitigate formula generated by inapplicable ('.') atomic coordinates
         if ( $formula eq '' ) {
             return undef;
         }
@@ -683,14 +691,14 @@ sub get_cod_status_from_error_flag
 #           'formula'    => 'H2 O'
 #           # Summary chemical formula calculated from the atomic coordinates
 #           'calcformula'=> 'H2 O'
-#       } 
+#       }
 # @return
 #       Number of distinct chemical elements.
 ##
 sub get_number_of_elements
 {
     my ( $formulae_values ) = @_;
-    
+
     my $formula;
     if ( $formulae_values->{'formula'} ne '?'  ) {
         $formula = $formulae_values->{'formula'};
@@ -698,7 +706,7 @@ sub get_number_of_elements
         $formula = $formulae_values->{'calcformula'};
     }
 
-    my $number_of_elements = 0;    
+    my $number_of_elements = 0;
     if ( defined $formula ) {
         $number_of_elements = count_number_of_elements( $formula )
     }
@@ -815,7 +823,7 @@ sub get_space_group_h_m_symbol
         }
     }
     if( !defined $space_group ) {
-        warn "WARNING, no space group information found\n";
+        warn "WARNING, no Hermann-Mauguin space group symbol found\n";
     } else {
         $space_group =~ s/^\s*|\s*$//g;
     }
@@ -948,7 +956,8 @@ sub validate_SQL_types
         next if !exists $types->{$key};
 
         if( $types->{$key} =~ /^(float|double|(small|medium)int)/i &&
-            !looks_like_number( $data->{$key} ) ) {
+            !(looks_like_number( $data->{$key} ) &&
+              $data->{$key} !~ /^[+-]?(inf|nan)/i) ) {
             warn "value of '$key' ('$data->{$key}') does not seem " .
                  'to be numeric -- value will be treated as undefined' . "\n";
             $data->{$key} = undef;
